==> owncloud-app-contacts-2%3A1.3.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/it.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contatti",
    "Address book name" : "Nome della rubrica",
    "Import" : "Importa",
    "No contacts in here" : "Nessun contatto qui",
    "Name" : "Nome",
    "Organization" : "Organizzazione",
    "Title" : "Titolo",
    "Add field ..." : "Aggiungi campo...",
    "Add contact" : "Aggiungi contatto",
    "No search result for {query}" : "Nessun risultato di ricerca per {query}",
    "All contacts" : "Tuuti i contatti",
    "Not grouped" : "Non raggruppati",
    "Post Office Box" : "Casella postale",
    "Postal Code" : "CAP",
    "City" : "Città",
    "State or province" : "Stato o regione",
    "Country" : "Stato",
    "Address" : "Indirizzo",
    "(new group)" : "(nuovo gruppo)",
    "New contact" : "Nuovo contatto",
    "{addressbook} shared by {owner}" : "{addressbook} condivisa da {owner}",
    "No contacts in file. Only VCard files are allowed." : "Nessun contatto nel file. Sono consentiti solo file vCard.",
    "Nickname" : "Pseudonimo",
    "Notes" : "Note",
    "Website" : "Sito web",
    "Federated Cloud ID" : "ID di cloud federata",
    "Home" : "Home",
    "Work" : "Lavoro",
    "Other" : "Altro",
    "Groups" : "Gruppi",
    "Birthday" : "Compleanno",
    "Email" : "Posta elettronica",
    "Instant messaging" : "Messaggistica istantanea",
    "Phone" : "Telefono",
    "Mobile" : "Cellulare",
    "Fax" : "Fax",
    "Fax home" : "Fax casa",
    "Fax work" : "Fax lavoro",
    "Pager" : "Cercapersone",
    "Voice" : "Voce",
    "Social Network" : "Rete sociale",
    "Settings" : "Impostazioni"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/it.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contatti",
    "Address book name" : "Nome della rubrica",
    "Import" : "Importa",
    "The selected image is too big (max 1MB)" : "L'immagine selezionata è troppo grande (max 1MB)",
    "No contacts in here" : "Nessun contatto qui",
    "Name" : "Nome",
    "Organization" : "Organizzazione",
    "Title" : "Titolo",
    "Add field ..." : "Aggiungi campo...",
    "+ New contact" : "+ Nuovo contatto",
    "No search result for {query}" : "Nessun risultato di ricerca per {query}",
    "_%n contact_::_%n contacts_" : ["%n contatto","%n contatti"],
    "Post office box" : "Casella postale",
    "Postal code" : "CAP",
    "City" : "Città",
    "State or province" : "Stato o regione",
    "Country" : "Stato",
    "Address" : "Indirizzo",
    "(new group)" : "(nuovo gruppo)",
    "Last name" : "Cognome",
    "First name" : "Nome",
    "Additional names" : "Nomi aggiuntivi",
    "Prefix" : "Prefisso",
    "Suffix" : "Suffisso",
    "All contacts" : "Tuuti i contatti",
    "Not grouped" : "Non raggruppati",
    "New contact" : "Nuovo contatto",
    "{addressbook} shared by {owner}" : "{addressbook} condivisa da {owner}",
    "No contacts in file. Only VCard files are allowed." : "Nessun contatto nel file. Sono consentiti solo file vCard.",
    "Nickname" : "Pseudonimo",
    "Detailed name" : "Nome dettagliato",
    "Notes" : "Note",
    "Website" : "Sito web",
    "Federated Cloud ID" : "ID di cloud federata",
    "Home" : "Home",
    "Work" : "Lavoro",
    "Other" : "Altro",
    "Groups" : "Gruppi",
    "Birthday" : "Compleanno",
    "Anniversary" : "Anniversario",
    "Date of death" : "Data di morte",
    "Email" : "Posta elettronica",
    "Instant messaging" : "Messaggistica istantanea",
    "Phone" : "Telefono",
    "Mobile" : "Cellulare",
    "Fax" : "Fax",
    "Fax home" : "Fax casa",
    "Fax work" : "Fax lavoro",
    "Pager" : "Cercapersone",
    "Voice" : "Voce",
    "Social network" : "Rete sociale",
    "Settings" : "Impostazioni"
},
"nplurals=2; plural=(n != 1);");
